@@ -12,9 +12,9 @@ from termuxmenu.console import Console
 from termuxmenu.logger import ErrorLog
 
 class DefaultConsole(Console):
-    def __init__(self,error_log: ErrorLog) -> None:
+    def __init__(self) -> None:
         super().__init__()
-        self.error_log = error_log
+        self.error_log = ErrorLog()
     @abstractclassmethod
     def main(self):
         pass
