@@ -18,6 +18,6 @@ class DefaultError(Error):
     def clear(self):
         self.errors.clear()
     def size(self) -> int:
-        return self.errors.count()
+        return len(self.errors)
     def add(self, string: str):
         return self.errors.append(string)
\ No newline at end of file
